pub struct JoinEdge {
pub left: u64,
pub right: u64,
pub selectivity: f64,
}Fields
left: u64Bitmask of relations on the left side of the equijoin.
right: u64Bitmask of relations on the right side of the equijoin.
selectivity: f64Selectivity of the join predicate (1 / max(distinct_left, distinct_right) for an equijoin).