pub struct IndexScanCandidate {
pub index_name: String,
pub table_name: String,
pub field: String,
pub predicate: Predicate,
pub scan_cost: f64,
}Expand description
Query-local physical index candidate supplied by an engine catalog.
The candidate already contains the scan cost for this predicate. This
keeps the planner independent of an engine’s index implementation while
allowing the final optimizer pass to emit a concrete
OperatorTree::IndexScan.
Fields
index_name: Stringtable_name: Stringfield: Stringpredicate: Predicatescan_cost: f64Trait Implementations
Sourceimpl Clone for IndexScanCandidate
impl Clone for IndexScanCandidate
Sourcefn clone(&self) -> IndexScanCandidate
fn clone(&self) -> IndexScanCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexScanCandidate
impl Debug for IndexScanCandidate
Sourceimpl PartialEq for IndexScanCandidate
impl PartialEq for IndexScanCandidate
impl StructuralPartialEq for IndexScanCandidate