Statement optimization and prepared-plan estimates over explicit catalog and retrieval inputs.
Modules
- executable
- Analyze executable plans before optimizer inputs and constant evaluation.
- prepared
- Custom-versus-generic plan selection and type-preserving parameter specialization.
- rule_
inputs - Prune mutation inputs discarded by rewrite rules before constant evaluation.
Structs
Traits
- Planner
Statistics Catalog - Loaded metadata needed to estimate relational access without depending on a storage provider.
- Retrieval
Source Costing - Access estimates supplied by the retrieval planner selected by the composition boundary.
- Statistics
Table State - Retain the loaded table generation across its dependent metadata reads.